@@ -5,6 +5,7 @@ from enum import Enum
 
 # code_preset.py -------------------------------------
 
+
 class ExistingCode(Enum):
     '''
     Preset values important for metaprogramming.
@@ -117,7 +118,6 @@ class CodeBuilder:
         return code_skeleton
 
 
-
 # code_builder.py ----------------------------------
 
 # Not necessary, but helps simplify the code.
@@ -217,6 +217,7 @@ class NautilusMenu:
 
 # Other misc methods to help out
 
+
     def get_next_item(self):
         '''
         Very niche, required in other methods.
@@ -229,6 +230,7 @@ class NautilusMenu:
 
 # Building the script body
 
+
     def build_script_body(self, name: str, items: list):
         '''
         Builds the body commands of the script.
@@ -306,10 +308,12 @@ class NautilusMenu:
         py_file.write(code)
         py_file.close()
 
+# Testing area
 
-# top_command/
-#     menu0/
-#         menu1/
-#               command1
-#         command2
-#     command3
+try:
+    def remove_linux_menu(name):
+        save_loc = os.path.join(os.path.expanduser('~'), '.local/share/nautilus-python/extensions', name + '*')
+        os.system('rm {}'.format(save_loc))
+
+except:
+    pass
