@@ -52,6 +52,7 @@ class ContextCommand:
 
      A command is an executable entry in a context-menu, where menus hold other commands.
     '''
+
     def __init__(self, name: str, command: str = None, python: 'function' = None):
         '''
         Do not specify both 'python' and 'command', either pass a python function or a command but not both.
@@ -117,3 +118,25 @@ class FastCommand:
         if platform.system() == 'Windows':
             windows_menus.FastRegistryCommand(
                 self.name, self.type, self.command, self.python).compile()
+
+try:
+    def removeMenu(name: str, type: str):
+        '''
+        Removes a menu/command entry from a context menu.
+
+        Requires the name of the menu and type of the menu
+        '''
+        from ..context_menu.windows_menus import remove_windows_menu
+
+        if platform.system() == 'Linux':
+            linux_menus.NautilusMenu(self.name, [ContextCommand(
+                self.name, command=self.command, python=self.python)], self.type).compile()
+        if platform.system() == 'Windows':
+            remove_windows_menu(name, type)
+
+
+    removeMenu('Foo menu', 'FILES')
+
+except:
+    # For testing
+    pass
