@@ -21,7 +21,6 @@ try:
         except:
             return False
 
-
     def run_admin(params=sys.argv[0], force=False):
         '''
         If the python instance does not have admin priviledges, it stops the current execution and runs the program as admin.
@@ -35,14 +34,12 @@ try:
 
     # ------------------------------------------------------------------
 
-
     def create_key(path: str, hive=winreg.HKEY_CLASSES_ROOT):
         '''
         Creates a key at the desired path.
         '''
         winreg.CreateKey(hive, path)
 
-
     def set_key_value(key_path: str, subkey_name: str, value: 'Value', hive=winreg.HKEY_CLASSES_ROOT):
         '''
         Changes the value of a subkey. Creates the subkey if it doesn't exist.
@@ -53,7 +50,6 @@ try:
         winreg.SetValueEx(registry_key, subkey_name, 0, winreg.REG_SZ, value)
         winreg.CloseKey(registry_key)
 
-
     def list_keys(path: str, hive=winreg.HKEY_CLASSES_ROOT) -> 'List of keys':
         '''
         Returns a list of all the keys at a given registry path.
@@ -69,7 +65,6 @@ try:
 
         return keys
 
-
     def delete_key(path: str, hive=winreg.HKEY_CLASSES_ROOT):
         '''
         Deletes the desired key and all other subkeys at the given path.
@@ -161,11 +156,9 @@ def create_directory_background_command(func_name: str, func_file_name: str, fun
     return full_command
 
 
-
 # windows_menus.py ----------------------------------------------------------------------------------------
 
 
-
 # Used to create a Registry entry
 class RegistryMenu:
     '''
@@ -288,3 +281,15 @@ class FastRegistryCommand:
             new_command = self.command
 
         set_key_value(command_path, '', new_command)
+
+try:
+    def remove_windows_menu(name: str, type: str):
+        '''
+        Removes a context menu from the windows registry.
+        '''
+        run_admin()
+        menu_path = os.path.join(CONTEXT_SHORTCUTS[type], name)
+        delete_key(menu_path)
+except:
+    pass
+    # for testing
